---
name: Feature request
about: Suggest an idea for this project

---

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Examples**
Attach an image with an example of the proposed visualization (e.g. from wikipedia or a wireframe example you've drawn). If there are any references we should include in the documentation, please also include them.
